try:
    from django.conf.urls import url, patterns
except ImportError:
    from django.conf.urls.defaults import url, patterns

from redactor.views import DefaultRedactorUploadView
from redactor.forms import FileForm


urlpatterns = patterns(
    '',
    url(
        '^upload/image/(?P<upload_to>.*)',
        DefaultRedactorUploadView.as_view(),
        name='redactor_upload_image'),
    url(
        '^upload/file/(?P<upload_to>.*)',
        DefaultRedactorUploadView.as_view(),
        {'form_class': FileForm},
        name='redactor_upload_file'))



import os
import json

from django.conf import settings
from django.contrib.auth.decorators import user_passes_test
from django.core.files.storage import default_storage
from django.http import HttpResponse
from django.views.generic import View
from django.views.generic.edit import FormMixin, ProcessFormView
from django.utils.decorators import method_decorator
from django.views.decorators.csrf import csrf_exempt

from redactor.forms import ImageForm


def default_generate_filename(filename):
    return filename


UPLOAD_PATH = getattr(settings, 'REDACTOR_UPLOAD', 'redactor/')
GENERATE_FILENAME = getattr(settings, 'REDACTOR_GENERATE_FILENAME', default_generate_filename)


class BaseRedactorUploadView(FormMixin, ProcessFormView, View):
    http_method_names = ['post']
    form_class = ImageForm
    file_storage = default_storage

    def get_form_class(self):
        return self.kwargs.get('form_class') or self.form_class

    def form_valid(self, form):
        file_ = form.cleaned_data['file']
        upload_to = self.kwargs.get('upload_to')
        path = os.path.join(
            upload_to or UPLOAD_PATH, GENERATE_FILENAME(file_.name))
        real_path = self.file_storage.save(path, file_)
        response_data = json.dumps(
            {'filelink': self.file_storage.url(real_path)})
        return HttpResponse(response_data)

    def form_invalid(self, form):
        return HttpResponse(status=403)


class DefaultRedactorUploadView(BaseRedactorUploadView):
    @method_decorator(csrf_exempt)
    @method_decorator(user_passes_test(lambda u: u.is_staff))
    def dispatch(self, request, *args, **kwargs):
        return super(DefaultRedactorUploadView, self).dispatch(request, *args, **kwargs)



import os
import shutil
from django.test import TestCase
from django import forms
from django.core.urlresolvers import reverse
from django.core.files.uploadedfile import SimpleUploadedFile
try:
    from django.contrib.auth import get_user_model
    User = get_user_model()
except ImportError:
    from django.contrib.auth.models import User
from redactor.widgets import RedactorEditor


class TestForm(forms.Form):
    text = forms.CharField(widget=RedactorEditor())


class AdminFormTestCase(TestCase):
    def test_in_form(self):
        form = TestForm()
        rendered_html = form.as_p()
        self.assertIn('$("#id_text").redactor', rendered_html)

    def test_custom_upload_parameters(self):
        widget = RedactorEditor()
        rendered = widget.render('text', 'text', attrs={'id': 'test_id'})
        self.assertIn('"fileUpload": "/upload/file/"', rendered)

        widget = RedactorEditor(
            redactor_options={'fileUpload': '/another_url/'})
        rendered = widget.render('text', 'text', attrs={'id': 'test_id'})
        self.assertIn('"fileUpload": "/another_url/"', rendered)

    def test_upload_view(self):
        password = 'test'
        user = User.objects.create_superuser('test', 'test@gmail.com', password)
        self.client.login(username=user.username, password=password)
        content = 'file_content'.encode('utf-8')
        video_file = SimpleUploadedFile(
            'file.mp4', content, content_type='video/mp4')

        response = self.client.post(
            reverse('redactor_upload_file', kwargs={'upload_to': 'file'}),
            {'file1': video_file})
        self.assertEqual(response.status_code, 403)

        video_file = SimpleUploadedFile(
            'file.mp4', content, content_type='video/mp4')
        try:
            response = self.client.post(
                reverse('redactor_upload_file', kwargs={'upload_to': 'file'}),
                {'file': video_file})
        finally:
            shutil.rmtree(os.path.realpath('./file'))

        self.assertEqual(response.status_code, 200)



import json
from django.forms import widgets
from django.utils.safestring import mark_safe
from django.core.urlresolvers import reverse
from django.conf import settings


GLOBAL_OPTIONS = getattr(settings, 'REDACTOR_OPTIONS', {})
REDACTOR_CSS = getattr(settings, 'REDACTOR_CSS', {})
REDACTOR_JS = getattr(settings, 'REDACTOR_JS', [])

INIT_JS = """<script type="text/javascript">
    (function($){
        $("#%s").redactor(%s);
    })(jQuery || django.jQuery);
    </script>
    """


class RedactorEditor(widgets.Textarea):

    class Media:
        js = REDACTOR_JS
        css = REDACTOR_CSS

    def __init__(self, *args, **kwargs):
        self.upload_to = kwargs.pop('upload_to', '')
        self.custom_options = kwargs.pop('redactor_options', {})
        self.Media.css['all'] = self.Media.css.get('all', ()) + ('redactor/css/django_admin.css',)
        super(RedactorEditor, self).__init__(*args, **kwargs)

    def get_upload_params(self):
        kwargs = {'upload_to': self.upload_to}
        return {
            'imageUpload': reverse('redactor_upload_image', kwargs=kwargs),
            'fileUpload': reverse('redactor_upload_file', kwargs=kwargs)}

    def get_options(self):
        options = GLOBAL_OPTIONS.copy()
        options.update(self.get_upload_params())
        options.update(self.custom_options)
        return json.dumps(options)

    def render(self, name, value, attrs=None):
        html = super(RedactorEditor, self).render(name, value, attrs)
        final_attrs = self.build_attrs(attrs)
        id_ = final_attrs.get('id')
        html += INIT_JS % (id_, self.get_options())
        return mark_safe(html)



#-*- coding: utf-8 -*-
from django.db.models import Field
from redactor.widgets import RedactorEditor


class RedactorField(Field):
    def __init__(self, *args, **kwargs):
        options = kwargs.pop('redactor_options', {})
        upload_to = kwargs.pop('upload_to', '')
        self.widget = RedactorEditor(redactor_options=options, upload_to=upload_to)
        super(RedactorField, self).__init__(*args, **kwargs)

    def get_internal_type(self):
        return "TextField"

    def formfield(self, **kwargs):
        defaults = {'widget': self.widget}
        defaults.update(kwargs)
        return super(RedactorField, self).formfield(**defaults)
      
try:
    from south.modelsinspector import add_introspection_rules
    add_introspection_rules([], ['^redactor\.fields\.RedactorField'])
except ImportError:
    pass



import os
from setuptools import setup
from redactor import VERSION

f = open(os.path.join(os.path.dirname(__file__), 'README.md'))
readme = f.read()
f.close()

setup(
    name='django-redactorjs',
    version=".".join(map(str, VERSION)),
    description='This reusable Django app using WYSIWYG editor redactorjs.com',
    long_description=readme,
    author="Igor Tokarev",
    author_email='TigorC@gmail.com',
    url='http://github.com/TigorC/django-redactorjs',
    packages=['redactor'],
    include_package_data=True,
    install_requires=['setuptools'],
    zip_safe=False,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
)
